WithEngine

Struct WithEngine 

pub struct WithEngine<'a, T, Ctx> { /* private fields */ }
A wrapper that pairs a coordinate reference with a custom transform context, enabling .using(&engine).to_frame::<F2>(&jd) style calls.

Example

ⓘ
let engine = AstroContext::new();
let result = direction.using(&engine).to_frame::<EclipticMeanJ2000>(&jd);

Implementations

Source

impl<'a, F: ReferenceFrame, Ctx> WithEngine<'a, Direction<F>, Ctx>
where Ctx: TransformContext,

pub fn to_frame<F2: ReferenceFrame>(&self, jd: &JulianDate) -> Direction<F2>
where (): FrameRotationProvider<F, F2>,

Rotates this direction to a new reference frame using the wrapped context.

Source

impl<'a, C, F, U, Ctx> WithEngine<'a, Position<C, F, U>, Ctx>
where C: ReferenceCenter<Params = ()>, Ctx: TransformContext, Ctx::Eph: Ephemeris, F: ReferenceFrame, U: LengthUnit,

pub fn to_frame<F2: ReferenceFrame>( &self, jd: &JulianDate, ) -> Position<C, F2, U>
where (): FrameRotationProvider<F, F2>,

Rotates this position to a new reference frame using the wrapped context.

pub fn to_center<C2: ReferenceCenter<Params = ()>>( &self, jd: &JulianDate, ) -> Position<C2, F, U>
where (): CenterShiftProvider<C, C2, F>,

Translates this position to a new reference center using the wrapped context.

pub fn to<C2: ReferenceCenter<Params = ()>, F2: ReferenceFrame>( &self, jd: &JulianDate, ) -> Position<C2, F2, U>
where (): CenterShiftProvider<C, C2, F> + FrameRotationProvider<F, F2>,

Combined center + frame transform using the wrapped context.