pub struct WithEngine<'a, T, Ctx> { /* private fields */ }Expand description
Implementations
Sourceimpl<'a, F: ReferenceFrame, Ctx> WithEngine<'a, Direction<F>, Ctx>where
Ctx: TransformContext,
impl<'a, F: ReferenceFrame, Ctx> WithEngine<'a, Direction<F>, Ctx>where
Ctx: TransformContext,
Sourcepub fn to_frame<F2: ReferenceFrame>(&self, jd: &JulianDate) -> Direction<F2>where
(): FrameRotationProvider<F, F2>,
pub fn to_frame<F2: ReferenceFrame>(&self, jd: &JulianDate) -> Direction<F2>where
(): FrameRotationProvider<F, F2>,
Rotates this direction to a new reference frame using the wrapped context.
Sourceimpl<'a, C, F, U, Ctx> WithEngine<'a, Position<C, F, U>, Ctx>where
C: ReferenceCenter<Params = ()>,
Ctx: TransformContext,
Ctx::Eph: Ephemeris,
F: ReferenceFrame,
U: LengthUnit,
impl<'a, C, F, U, Ctx> WithEngine<'a, Position<C, F, U>, Ctx>where
C: ReferenceCenter<Params = ()>,
Ctx: TransformContext,
Ctx::Eph: Ephemeris,
F: ReferenceFrame,
U: LengthUnit,
Sourcepub fn to_frame<F2: ReferenceFrame>(
&self,
jd: &JulianDate,
) -> Position<C, F2, U>where
(): FrameRotationProvider<F, F2>,
pub fn to_frame<F2: ReferenceFrame>(
&self,
jd: &JulianDate,
) -> Position<C, F2, U>where
(): FrameRotationProvider<F, F2>,
Rotates this position to a new reference frame using the wrapped context.
Sourcepub fn to_center<C2: ReferenceCenter<Params = ()>>(
&self,
jd: &JulianDate,
) -> Position<C2, F, U>where
(): CenterShiftProvider<C, C2, F>,
pub fn to_center<C2: ReferenceCenter<Params = ()>>(
&self,
jd: &JulianDate,
) -> Position<C2, F, U>where
(): CenterShiftProvider<C, C2, F>,
Translates this position to a new reference center using the wrapped context.
Sourcepub fn to<C2: ReferenceCenter<Params = ()>, F2: ReferenceFrame>(
&self,
jd: &JulianDate,
) -> Position<C2, F2, U>
pub fn to<C2: ReferenceCenter<Params = ()>, F2: ReferenceFrame>( &self, jd: &JulianDate, ) -> Position<C2, F2, U>
Combined center + frame transform using the wrapped context.